---
delivery_guarantee: "best_effort"
component_title: "Syslog"
description: "The Vector `syslog` source ingests data through the Syslog protocol and outputs `log` events."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22source%3A+syslog%22
min_version: null
operating_systems: ["Linux","MacOS","Windows"]
service_name: "Syslog"
sidebar_label: "syslog|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/sources/syslog.rs
status: "prod-ready"
title: "Syslog Source"
unsupported_operating_systems: []
---

The Vector `syslog` source ingests data through the Syslog protocol and [outputs `log` events](#output).

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sources/syslog.md.erb
-->

## Configuration

import Tabs from '@theme/Tabs';

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>

import TabItem from '@theme/TabItem';

<TabItem value="common">

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sources.my_source_id]
  # REQUIRED - General
  type = "syslog" # must be: "syslog"
  mode = "tcp" # example, enum

  # OPTIONAL - Context
  host_key = "host" # default

  # OPTIONAL - General
  address = "0.0.0.0:9000" # example, no default, relevant when mode = "tcp" or mode = "udp"
  path = "/path/to/socket" # example, no default, relevant when mode = "unix"
```

</TabItem>
<TabItem value="advanced">

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sources.my_source_id]
  # REQUIRED - General
  type = "syslog" # must be: "syslog"
  mode = "tcp" # example, enum

  # OPTIONAL - Context
  host_key = "host" # default

  # OPTIONAL - General
  address = "0.0.0.0:9000" # example, no default, relevant when mode = "tcp" or mode = "udp"
  max_length = 102400 # default, bytes
  path = "/path/to/socket" # example, no default, relevant when mode = "unix"
```

</TabItem>
</Tabs>

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["0.0.0.0:9000","systemd","systemd#2"]}
  groups={[]}
  name={"address"}
  path={null}
  relevantWhen={{"mode":["tcp","udp"]}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### address

The TCP or UDP address to listen for connections on, or "systemd#N" to use the Nth socket passed by systemd socket activation.


</Field>


<Field
  common={true}
  defaultValue={"host"}
  enumValues={null}
  examples={["host"]}
  groups={[]}
  name={"host_key"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### host_key

The key name added to each event representing the current host. This can also be globally set via the [global [`host_key`](#host_key) option][docs.reference.global-options#host_key]. See [Context](#context) for more info.


</Field>


<Field
  common={false}
  defaultValue={102400}
  enumValues={null}
  examples={[102400]}
  groups={[]}
  name={"max_length"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"bytes"}
  >

### max_length

The maximum bytes size of incoming messages before they are discarded.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={{"tcp":"Read incoming Syslog data over the TCP protocol.","udp":"Read incoming Syslog data over the UDP protocol.","unix":"Read uncoming Syslog data through a Unix socker."}}
  examples={["tcp","udp","unix"]}
  groups={[]}
  name={"mode"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### mode

The input mode.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/socket"]}
  groups={[]}
  name={"path"}
  path={null}
  relevantWhen={{"mode":"unix"}}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### path

The unix socket path. *This should be absolute path.*



</Field>


</Fields>

## Output

The `syslog` source ingests data through the Syslog protocol and [outputs `log` events](#output).
For example:

```javascript
{
  "appname": "app-name",
  "facility": "1",
  "host": "my.host.com",
  "message": "<13>Feb 13 20:07:26 74794bfb6795 root[8539]: i am foobar",
  "msgid": "ID47",
  "procid": 8710,
  "severity": "notice",
  "timestamp": "2019-11-01T21:15:47+00:00",
  "version": 1
}
```
More detail on the output schema is below.

<Fields filters={true}>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["app-name"]}
  groups={[]}
  name={"appname"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### appname

The appname extracted from the Syslog formatted line. If a appname is not found, then the key will not be added.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["1"]}
  groups={[]}
  name={"facility"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### facility

The facility extracted from the Syslog line. If a facility is not found, then the key will not be added.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["my.host.com"]}
  groups={[]}
  name={"host"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### host

The hostname extracted from the  Syslog line. If a hostname is not found, then Vector will use the upstream hostname. In the case where [`mode`](#mode) = `"unix"` the socket path will be used. This key can be renamed via the [`host_key`](#host_key) option.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["<13>Feb 13 20:07:26 74794bfb6795 root[8539]: i am foobar"]}
  groups={[]}
  name={"message"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### message

The raw message, unaltered.
 See [Parsing](#parsing) for more info.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["ID47"]}
  groups={[]}
  name={"msgid"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### msgid

The msgid extracted from the Syslog line. If a msgid is not found, then the key will not be added.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[8710]}
  groups={[]}
  name={"procid"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  >

### procid

The procid extracted from the Syslog line. If a procid is not found, then the key will not be added.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["notice"]}
  groups={[]}
  name={"severity"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### severity

The severity extracted from the Syslog line. If a severity is not found, then the key will not be added.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["2019-11-01T21:15:47+00:00"]}
  groups={[]}
  name={"timestamp"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"timestamp"}
  unit={null}
  >

### timestamp

The timestamp extracted from the incoming line. If a timestamp is not found, then Vector will use the current time.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"version"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  >

### version

The version extracted from the Syslog line. If a version is not found, then the key will not be added.


</Field>


</Fields>

## How It Works

### Context

By default, the `syslog` source will add context
keys to your events via the [`host_key`](#host_key)
options.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.

### Line Delimiters

Each line is read until a new line delimiter (the `0xA` byte) is found.

### Parsing

Vector makes a _best effort_ to parse the various Syslog formats out in the
wild. This includes [RFC 5424][urls.syslog_5424], [RFC 3164][urls.syslog_3164],
and other common variations (such as the Nginx Syslog style). It's unfortunate
that the Syslog specification is not more accurately followed, but we hope
Vector insulates you from these diviations.

If parsing fails, Vector will include the entire Syslog line in the [`message`](#message)
key. If you find this happening often, we recommend using the
[`socket` source][docs.sources.socket] combined with the
[`regex_parser` transform][docs.transforms.regex_parser] to implement your own
ingestion and parsing scheme. Or, [open an issue][urls.new_feature_request]
requesting support for your specific format.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.reference.global-options#host_key]: /docs/reference/global-options/#host_key
[docs.sources.socket]: /docs/reference/sources/socket/
[docs.transforms.regex_parser]: /docs/reference/transforms/regex_parser/
[urls.new_feature_request]: https://github.com/timberio/vector/issues/new?labels=type%3A+new+feature
[urls.syslog_3164]: https://tools.ietf.org/html/rfc3164
[urls.syslog_5424]: https://tools.ietf.org/html/rfc5424
