---
component_title: "Concat"
description: "The Vector `concat` transform accepts and outputs `log` events allowing you to concat (substrings) of other fields to a new one."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+concat%22
min_version: null
service_name: "Concat"
sidebar_label: "concat|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/concat.rs
status: "beta"
title: "Concat Transform"
---

The Vector `concat` transform accepts and [outputs `log` events](#output) allowing you to concat (substrings) of other fields to a new one.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/concat.md.erb
-->

## Configuration

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[transforms.my_transform_id]
  # REQUIRED
  type = "concat" # must be: "concat"
  inputs = ["my-source-id"] # example
  items = ["first[..3]", "second[-5..]", "third[3..6]"] # example
  target = "dest_field_name" # example

  # OPTIONAL
  joiner = " " # default
```

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[["first[..3]","second[-5..]","third[3..6]"]]}
  groups={[]}
  name={"items"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"[string]"}
  unit={null}
  >

### items

A list of substring definitons in the format of source_field[start..end]. For both start and end negative values are counted from the end of the string.


</Field>


<Field
  common={true}
  defaultValue={" "}
  enumValues={null}
  examples={[" ",",","_","+"]}
  groups={[]}
  name={"joiner"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### joiner

The string that is used to join all items.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["dest_field_name"]}
  groups={[]}
  name={"target"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### target

The name for the new label.


</Field>


</Fields>

## Output

The `concat` transform accepts and [outputs `log` events](#output) allowing you to concat (substrings) of other fields to a new one.
For example:


Given the following input log event:

```json
{
  "message": "Hello world",
  "month": "12",
  "day": "25",
  "year": "2020"
}
```

And the following example configuration:

```toml
[transforms.concat_date]
  type = "concat"
  items = ["month", "day", "year"]
  target = "date"
  joiner = "/"
```

A log event will be output with the following structure:

```json
{
  "message": "Hello world",
  "date": "12/25/2020", // <-- new field
  "month": "12",
  "day": "25",
  "year": "2020"
}
```

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
