---
component_title: "Rename Fields"
description: "The Vector `rename_fields` transform accepts and outputs `log` events allowing you to rename one or more log fields."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22transform%3A+rename_fields%22
min_version: null
service_name: "Rename Fields"
sidebar_label: "rename_fields|[\"log\"]"
source_url: https://github.com/timberio/vector/tree/master/src/transforms/rename_fields.rs
status: "prod-ready"
title: "Rename Fields Transform"
---

The Vector `rename_fields` transform accepts and [outputs `log` events](#output) allowing you to rename one or more log fields.

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/transforms/rename_fields.md.erb
-->

## Configuration

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[transforms.my_transform_id]
  # REQUIRED - General
  type = "rename_fields" # must be: "rename_fields"
  inputs = ["my-source-id"] # example

  # REQUIRED - Fields
  [transforms.my_transform_id.fields]
    old field name = "new field name" # example
```

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"fields"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"table"}
  unit={null}
  >

### fields

A table of old-key/new-key pairs representing the keys to be moved in the event.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[{"old field name":"new field name"}]}
  groups={[]}
  name={"`[field-name]`"}
  path={"fields"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"*"}
  unit={null}
  >

#### `[field-name]`

The name of the field to move. Use `.` for adding nested fields.


</Field>


</Fields>

</Field>


</Fields>

## Output

The `rename_fields` transform accepts and [outputs `log` events](#output) allowing you to rename one or more log fields.
For example:


Given the following configuration:

<CodeHeader fileName="vector.toml" />

```toml
[transforms.my_transform]
  type = "rename_fields"
  inputs = [...]

  [transforms.my_transform.fields]
    old_field = "new_field"
    old_nested.nested = "new_nested.nested",
```

## How It Works

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.



### Key Conflicts

Keys specified in this transform will replace existing keys.

### Nested Fields

The `rename_fields` transform will support dotted keys or [TOML
tables][urls.toml_table]. We recommend the dotted key syntax since it is less
verbose for this usecase:

```
[transforms.<transform-id>]
  # ...

  [transforms.<transform-id>.fields]
    parent.child.grandchild = "other_parent.child"
```

Results in:

```json
{
  "parent.child.grandchild": "other_parent.child"
}
```

Learn more about how [`log` events][docs.data-model.log] are structured.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[urls.toml_table]: https://github.com/toml-lang/toml#table
